summaryrefslogtreecommitdiff
path: root/render/box.h
diff options
context:
space:
mode:
Diffstat (limited to 'render/box.h')
-rw-r--r--render/box.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/render/box.h b/render/box.h
index 144b4a74a..4c87d1c52 100644
--- a/render/box.h
+++ b/render/box.h
@@ -123,7 +123,8 @@ typedef enum {
PRINTED = 1 << 2, /* box has already been printed */
PRE_STRIP = 1 << 3, /* PRE tag needing leading newline stripped */
CLONE = 1 << 4, /* continuation of previous box from wrapping */
- MEASURED = 1 << 5 /* text box width has been measured */
+ MEASURED = 1 << 5, /* text box width has been measured */
+ HAS_HEIGHT = 1 << 6 /* box has height */
} box_flags;
/* Sides of a box */